"""Jivas Graph CLI tool."""

from jvmanager.commands.launch import launch
from jvmanager.group import jvmanager

# Register command groups
jvmanager.add_command(launch)


if __name__ == "__main__":
    jvmanager()  # pragma: no cover



"""Command group for deploying and interfacing with the Jivas Manager."""

from importlib import resources

import click
from fastapi import FastAPI, Request
from fastapi.middleware.cors import CORSMiddleware
from fastapi.responses import FileResponse
from fastapi.staticfiles import StaticFiles
from uvicorn import run

from jvmanager.group import jvmanager


@jvmanager.command()
@click.option("--port", default=8990, help="Port for the manager to launch on.")
@click.option("--host", default="0.0.0.0", help="Host for the manager to launch on.")
def launch(port: int, host: str) -> None:
    """Launch the Jivas Manager on the specified port."""
    click.echo(f"Launching Jivas Manager on port {port}...")
    app = FastAPI(title="Jivas Studio API")

    app.add_middleware(
        CORSMiddleware,
        allow_origins=["*"],
        allow_credentials=True,
        allow_methods=["*"],
        allow_headers=["*"],
    )

    with resources.path("jvmanager.manager", "client") as client_path:
        client_dir = client_path

        app.mount(
            "/assets", StaticFiles(directory=client_dir / "assets"), name="assets"
        )
        app.mount("/dist", StaticFiles(directory=client_dir / "dist"), name="dist")

        @app.get("/favicon.ico")
        async def favicon() -> FileResponse:
            return FileResponse(client_dir / "favicon.ico")

        @app.get("/{full_path:path}")
        async def serve_spa(request: Request, full_path: str) -> FileResponse:
            """Serve the SPA for all routes."""
            requested_file = client_dir / full_path
            if requested_file.exists() and requested_file.is_file():
                return FileResponse(requested_file)
            index_file = client_dir / "index.html"
            return FileResponse(index_file)

        run(app, host=host, port=port)



"""Jivas Manager CLI tool."""

import click

from jvmanager import __version__  # type: ignore[attr-defined]


@click.group()
@click.version_option(__version__, prog_name="jvmanager")
def jvmanager() -> None:
    """Jivas Manager CLI tool."""
    pass  # pragma: no cover



"""setup.py for jvmanager package"""

import os

from setuptools import find_packages, setup


def get_version() -> str:
    """Get the package version from the __init__ file."""
    version_file = os.path.normpath(
        os.path.join(os.path.dirname(__file__), "..", "__init__.py")
    )
    with open(version_file) as f:
        for line in f:
            if line.startswith("__version__"):
                delim = '"' if '"' in line else "'"
                return line.split(delim)[1]
    raise RuntimeError("Version not found.")


with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="jvmanager",
    version=get_version(),
    packages=find_packages(),
    long_description=long_description,
    install_requires=[
        "click",
        "fastapi",
        "uvicorn",
        "python-multipart",
    ],
    package_data={
        "jvmanager": ["manager/client/**"],
    },
    entry_points={
        "console_scripts": [
            "jvmanager = jvmanager.cli:jvmanager",
        ],
    },
)
